/* Dies ist unsere Kradio Klasse, sie verkrpert nur unsere
 * Oberflche 
 * Written Nov 1998 Carsten Gro (carsten@sol.wohnheim.uni-ulm.de)
 * Orientiert sich ein bichen an kexample von Matthias Ettrich
 */

/** 
 * Das KRadio Programm
 * 
 */
#ifndef STATIONSDIALOG_H
#define STATIONSDIALOG_H


#include <kapp.h>
#include <qpopupmenu.h>
#include <qdialog.h>
#include <qgroupbox.h>
#include <qpushbutton.h>
#include "kderadio.h"
#include "radioctrl.h"

class StationsDialog : public QDialog {
	Q_OBJECT
	public:
		StationsDialog(QWidget *, const char *, double);
		char * getStation();
	public slots:
		void accept(void);
		void slotChangeText(const QString &);
	protected:
	        QPushButton     * pOk, * pCancel;
	        QLabel          * pFrequenzAnzeige;
	        QLineEdit       * pStationsAnzeige;
	        QGroupBox       * pGroupBox;
		char		Station[40];	        
		char            a[30];
};

#endif /* STATIONSDIALOG_H */
